Available on crate feature
client and (crate features http or socks5) only.Expand description
Standard, blocking pump driving the proxy coroutines over any
Read + Write stream.
On success the stream is a live tunnel to the target, positioned at its first byte, ready for the caller’s TLS handshake or plaintext protocol.
Enums
- Proxy
Client Error - Errors returned by the client pump.
Functions
- connect_
http http - Runs the HTTP
CONNECThandshake onstream(already connected to the proxy), tunnelling tohost:portand sendingProxy-Authorization: Basicifcredentialsare provided. - connect_
socks5 socks5 - Runs the SOCKS5
CONNECThandshake onstream(already connected to the proxy), tunnelling totargetand authenticating withcredentialsif the proxy asks for username/password.