Module http

Module http 

Available on crate feature http only.
HTTP proxy tunnelling.

connect is the client CONNECT handshake coroutine (RFC 9110 9.3.6). CONNECT exists only to open a proxy tunnel, so it lives in this proxy crate rather than in a general HTTP crate.

Modules

connect
I/O-free coroutine running the HTTP CONNECT tunnel handshake (RFC 9110 9.3.6).